@@ -3,6 +3,7 @@
 from time import time, sleep
 import wx
 import sys
+import config
 
 from collective.buildout.cluster.states import *
 
@@ -25,7 +26,7 @@ class Operate(OperatePlatform):
     tests for the state """
 
     def getStatus(self, win=None):
-        print "getStatus called"
+        if config.debug: print "getStatus called"
         status = self.isRunning()
         
         if win:
